@@ -42,16 +42,16 @@
 #' @examples
 #' if(interactive()){
 #'   texts <- c("p1", "p2", "", "p4", "p5")
-#'   hrefs <- c("https://unsplash.it/1200/768.jpg?image=251",
-#'              "https://unsplash.it/1200/768.jpg?image=252",
+#'   hrefs <- c("https://github.com/lz100/spsComps/blob/master/img/1.jpg?raw=true",
+#'              "https://github.com/lz100/spsComps/blob/master/img/2.jpg?raw=true",
 #'              "",
-#'              "https://unsplash.it/1200/768.jpg?image=254",
-#'              "https://unsplash.it/1200/768.jpg?image=255")
-#'   images <- c("https://unsplash.it/600.jpg?image=251",
-#'               "https://unsplash.it/600.jpg?image=252",
-#'               "https://unsplash.it/600.jpg?image=253",
-#'               "https://unsplash.it/600.jpg?image=254",
-#'               "https://unsplash.it/600.jpg?image=255")
+#'              "https://github.com/lz100/spsComps/blob/master/img/4.jpg?raw=true",
+#'              "https://github.com/lz100/spsComps/blob/master/img/5.jpg?raw=true")
+#'   images <- c("https://github.com/lz100/spsComps/blob/master/img/1.jpg?raw=true",
+#'               "https://github.com/lz100/spsComps/blob/master/img/2.jpg?raw=true",
+#'               "https://github.com/lz100/spsComps/blob/master/img/3.jpg?raw=true",
+#'               "https://github.com/lz100/spsComps/blob/master/img/4.jpg?raw=true",
+#'               "https://github.com/lz100/spsComps/blob/master/img/5.jpg?raw=true")
 #'   library(shiny)
 #'
 #'   ui <- fluidPage(
@@ -237,10 +237,9 @@ hrefTab <- function(label_texts,
     if (length(bg_colors) > 1) assert_that(length(label_texts) == length(bg_colors))
     if (length(text_colors) > 1) assert_that(length(label_texts) == length(text_colors))
 
-    hrefs[hrefs != ""] <- glue('href="{hrefs[hrefs != ""]}"')
     href_hover <- rep("", length(hrefs))
     href_hover[hrefs == ""] <- "nohover"
-
+    hrefs[hrefs == ""] <- "javascript:null;"
     div(
         id = Id, class = "col", ... ,
         p(class = "h4",
@@ -249,7 +248,7 @@ hrefTab <- function(label_texts,
         div(
             HTML(glue('
             <a
-              {hrefs}
+              href="{hrefs}"
               class="href-button sps-tab-link {href_hover}"
               style="background-color: {bg_colors}; color: {text_colors};"
              >
@@ -414,12 +413,12 @@ hrefTable <- function(item_titles,
         )
     btns <- mapply(
         function(label, href, bg_color, text_color) {
-            href[href != ""] <- glue('href="{href[href != ""]}"')
             href_hover <- rep("", length(href))
             href_hover[href == ""] <- "nohover"
+            href[href == ""] <- "javascript:null;"
             glue('
             <a
-              {href}
+              href="{href}"
               class="href-button {href_hover} sps-tab-link"
               style="background-color: {bg_color}; color: {text_color};"
             >
@@ -718,6 +717,7 @@ tabTitle <- function(title, ...){
 #' @examples
 #' if(interactive()){
 #'     library(shiny)
+#'     library(magrittr)
 #'     ui <- fluidPage(
 #'         column(2),
 #'         column(
@@ -733,7 +733,20 @@ tabTitle <- function(title, ...){
 #'                     title = "title b",
 #'                     content = "popover works on a link",
 #'                     placement = "bottom"
-#'                 )
+#'                 ),
+#'             div(
+#'               tags$b("general element"),
+#'               style =
+#'                 '
+#'               height: 100px;
+#'               background-color: cornflowerblue;
+#'             '
+#'             ) %>%
+#'               bsHoverPopover(
+#'                 title = "general element",
+#'                 content = "popover works on a 'div'",
+#'                 placement = "right"
+#'               )
 #'         )
 #'
 #'     )
@@ -870,9 +883,7 @@ spsLoader <- function(id=NULL){
 #'             style = "border: 1px black solid; background-color: red;",
 #'             p("This block's is not matched with others")
 #'         ),
-#'         heightMatcher("a", "b"),
-#'         spsDepend("basic", css = FALSE),
-#'         spsDepend("basic", js = FALSE)
+#'         heightMatcher("a", "b")
 #'     )
 #'
 #'     server <- function(input, output, session) {
@@ -1017,9 +1028,9 @@ spsGoTop <- function(
 #'
 #' @examples
 #' if(interactive()){
-#'     library(shiny)
-#'     code <-
-#'         '
+#'   library(shiny)
+#'   my_code <-
+#'     '
 #'     # load package and data
 #'     library(ggplot2)
 #'     data(mpg, package="ggplot2")
@@ -1034,8 +1045,8 @@ spsGoTop <- function(
 #'            x="cty",
 #'            title="Jittered Points")
 #'     '
-#'     html_code <-
-#'         '
+#'   html_code <-
+#'     '
 #'     <!DOCTYPE html>
 #'     <html>
 #'     <body>
@@ -1047,68 +1058,68 @@ spsGoTop <- function(
 #'     </body>
 #'     </html>
 #'     '
-#'     ui <- fluidPage(
-#'         fluidRow(
-#'             column(
-#'                 6,
-#'                 h3("Display by modal"),
-#'                 column(
-#'                     6, h4("default"),
-#'                     spsCodeBtn(id = "a", code)
-#'                 ),
-#'                 column(
-#'                     6, h4("change color and shape"),
-#'                     spsCodeBtn(
-#'                         id = "b", c(code, code),
-#'                         color = "red", shape = "circular")
-#'                 )
-#'             ),
-#'             column(
-#'                 6,
-#'                 h3("Display by collapse"),
-#'                 column(
-#'                     6, h4("collapse"),
-#'                     spsCodeBtn(id = "c", code, display = "collapse")
-#'                 ),
-#'                 column(
-#'                     6, h4("different programming language"),
-#'                     spsCodeBtn(
-#'                         id = "d", html_code,
-#'                         language = "html", display = "collapse")
-#'                 )
-#'             )
+#'   ui <- fluidPage(
+#'     fluidRow(
+#'       column(
+#'         6,
+#'         h3("Display by modal"),
+#'         column(
+#'           6, h4("default"),
+#'           spsCodeBtn(id = "a", my_code)
 #'         ),
-#'         fluidRow(
-#'             column(
-#'                 6,
-#'                 h3("Update code"),
-#'                 spsCodeBtn(
-#'                     "update-code",
-#'                     "# No code here",
-#'                     display = "collapse"
-#'                 ),
-#'                 actionButton("update", "change code in the left `spsCodeBtn`"),
-#'                 actionButton("changeback", "change it back")
-#'             )
+#'         column(
+#'           6, h4("change color and shape"),
+#'           spsCodeBtn(
+#'             id = "b", c(my_code, my_code),
+#'             color = "red", shape = "circular")
 #'         )
+#'       ),
+#'       column(
+#'         6,
+#'         h3("Display by collapse"),
+#'         column(
+#'           6, h4("collapse"),
+#'           spsCodeBtn(id = "c", my_code, display = "collapse")
+#'         ),
+#'         column(
+#'           6, h4("different programming language"),
+#'           spsCodeBtn(
+#'             id = "d", html_code,
+#'             language = "html", display = "collapse")
+#'         )
+#'       )
+#'     ),
+#'     fluidRow(
+#'       column(
+#'         6,
+#'         h3("Update code"),
+#'         spsCodeBtn(
+#'           "update-code",
+#'           "# No code here",
+#'           display = "collapse"
+#'         ),
+#'         actionButton("update", "change code in the left `spsCodeBtn`"),
+#'         actionButton("changeback", "change it back")
+#'       )
 #'     )
+#'   )
 #'
-#'     server <- function(input, output, session) {
-#'         observeEvent(input$update, {
-#'             shinyAce::updateAceEditor(
-#'                 session, editorId = "update-code-ace",
-#'                 value = "# code has changed!\n 1+1"
-#'             )
-#'         })
-#'         observeEvent(input$changeback, {
-#'             shinyAce::updateAceEditor(
-#'                 session, editorId = "update-code-ace",
-#'                 value = "# No code here"
-#'             )
-#'         })
-#'     }
+#'   server <- function(input, output, session) {
+#'     observeEvent(input$update, {
+#'       shinyAce::updateAceEditor(
+#'         session, editorId = "update-code-ace",
+#'         value = "# code has changed!\n 1+1"
+#'       )
+#'     })
+#'     observeEvent(input$changeback, {
+#'       shinyAce::updateAceEditor(
+#'         session, editorId = "update-code-ace",
+#'         value = "# No code here"
+#'       )
+#'     })
+#'   }
 #'
-#'     shinyApp(ui, server)
+#'   shinyApp(ui, server)
 #' }
 spsCodeBtn <- function(
     id,
